# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field
from ai_assistant_server_connector.models.ai_assistant_get import AiAssistantGet
from ai_assistant_server_connector.models.emphemeral_credentials import EmphemeralCredentials

class AIAssistantSessionStart(BaseModel):
    """
    AIAssistantSessionStart
    """
    ai_assistant: AiAssistantGet = Field(...)
    credentials: EmphemeralCredentials = Field(...)
    __properties = ["ai_assistant", "credentials"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AIAssistantSessionStart:
        """Create an instance of AIAssistantSessionStart from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of ai_assistant
        if self.ai_assistant:
            _dict['ai_assistant'] = self.ai_assistant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of credentials
        if self.credentials:
            _dict['credentials'] = self.credentials.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AIAssistantSessionStart:
        """Create an instance of AIAssistantSessionStart from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AIAssistantSessionStart.parse_obj(obj)

        _obj = AIAssistantSessionStart.parse_obj({
            "ai_assistant": AiAssistantGet.from_dict(obj.get("ai_assistant")) if obj.get("ai_assistant") is not None else None,
            "credentials": EmphemeralCredentials.from_dict(obj.get("credentials")) if obj.get("credentials") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_list_get import ResponseWrapperListAiAssistantListGet  # noqa: E501

class TestResponseWrapperListAiAssistantListGet(unittest.TestCase):
    """ResponseWrapperListAiAssistantListGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListAiAssistantListGet:
        """Test ResponseWrapperListAiAssistantListGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListAiAssistantListGet`
        """
        model = ResponseWrapperListAiAssistantListGet()  # noqa: E501
        if include_optional:
            return ResponseWrapperListAiAssistantListGet(
                done = True,
                error = '',
                result = [
                    ai_assistant_server_connector.models.ai_assistant_list_get.AiAssistantListGet(
                        allow_text = True, 
                        allow_voice = True, 
                        approved_urls = [
                            ''
                            ], 
                        avatar_id = '', 
                        banned_keywords = [
                            ''
                            ], 
                        conversation_starter = '', 
                        conversation_style = 'formal', 
                        created_at = 56, 
                        deleted_at = 56, 
                        function = 'support', 
                        id = 56, 
                        is_active = True, 
                        is_available = True, 
                        is_live = True, 
                        knowledgebase_state = ai_assistant_server_connector.models.knowledgebase_state.KnowledgebaseState(
                            course_data = null, ), 
                        last_updated_at = 56, 
                        name = '', 
                        prefer_voice = True, 
                        system_prompt = '', 
                        system_prompt_support = '', 
                        system_prompt_tutor = '', 
                        voice_id = 56, )
                    ]
            )
        else:
            return ResponseWrapperListAiAssistantListGet(
                done = True,
        )
        """

    def testResponseWrapperListAiAssistantListGet(self):
        """Test ResponseWrapperListAiAssistantListGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conint, conlist

class AiAssistantGoalCreateUpdate(BaseModel):
    """
    AiAssistantGoalCreateUpdate
    """
    additional_prompt: StrictStr = Field(...)
    course_ids: conlist(StrictInt) = Field(...)
    engagement: Optional[conint(strict=True, le=100, ge=0)] = 50
    engagement_opt_out_duration: Optional[conint(strict=True, ge=0)] = 0
    engagement_preset_id: Optional[StrictInt] = None
    id: Optional[StrictInt] = None
    is_active: StrictBool = Field(...)
    max_engagement_count: Optional[conint(strict=True, ge=0)] = 0
    max_engagement_period: Optional[conint(strict=True, ge=0)] = 0
    max_total_engagement_count: Optional[conint(strict=True, ge=0)] = 0
    name: StrictStr = Field(...)
    page_url: Optional[StrictStr] = None
    primary_course_id: Optional[StrictInt] = None
    __properties = ["additional_prompt", "course_ids", "engagement", "engagement_opt_out_duration", "engagement_preset_id", "id", "is_active", "max_engagement_count", "max_engagement_period", "max_total_engagement_count", "name", "page_url", "primary_course_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AiAssistantGoalCreateUpdate:
        """Create an instance of AiAssistantGoalCreateUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AiAssistantGoalCreateUpdate:
        """Create an instance of AiAssistantGoalCreateUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AiAssistantGoalCreateUpdate.parse_obj(obj)

        _obj = AiAssistantGoalCreateUpdate.parse_obj({
            "additional_prompt": obj.get("additional_prompt"),
            "course_ids": obj.get("course_ids"),
            "engagement": obj.get("engagement") if obj.get("engagement") is not None else 50,
            "engagement_opt_out_duration": obj.get("engagement_opt_out_duration") if obj.get("engagement_opt_out_duration") is not None else 0,
            "engagement_preset_id": obj.get("engagement_preset_id"),
            "id": obj.get("id"),
            "is_active": obj.get("is_active"),
            "max_engagement_count": obj.get("max_engagement_count") if obj.get("max_engagement_count") is not None else 0,
            "max_engagement_period": obj.get("max_engagement_period") if obj.get("max_engagement_period") is not None else 0,
            "max_total_engagement_count": obj.get("max_total_engagement_count") if obj.get("max_total_engagement_count") is not None else 0,
            "name": obj.get("name"),
            "page_url": obj.get("page_url"),
            "primary_course_id": obj.get("primary_course_id")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.3.1+2484675028"

# Define package exports
__all__ = [
    "AiAssistantApiApi",
    "AssistantsApi",
    "AssistantsServerApi",
    "AvatarsApi",
    "DefaultApi",
    "GoalEngagementPresetsApi",
    "RagApi",
    "ServerApi",
    "VoicesApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AIAssistantReponseStreamRequest",
    "AIAssistantSessionStart",
    "AiAssistantCustomSkillCreate",
    "AiAssistantCustomSkillGet",
    "AiAssistantCustomSkillPatch",
    "AiAssistantCustomSkillUpdate",
    "AiAssistantGet",
    "AiAssistantGoalCreate",
    "AiAssistantGoalCreateUpdate",
    "AiAssistantGoalGet",
    "AiAssistantLexiconItem",
    "AiAssistantLexiconItemCreateOrUpdate",
    "AiAssistantLexiconItemNew",
    "AiAssistantListGet",
    "AiAssistantNew",
    "AiAssistantSettingToggle",
    "AiAssistantSetupFromRoot",
    "AiAssistantSkillSettingGet",
    "AiAssistantToolSettingGet",
    "AiAssistantUpdate",
    "AssistantFunction",
    "AvatarOptionGet",
    "ChatHistoryChatContent",
    "ChatHistoryItem",
    "ChatMessageAttachment",
    "ChatMessageAttachmentType",
    "ChatRole",
    "CollectionState",
    "CollectionStatus",
    "ConversationStyle",
    "CourseModulePublic",
    "CoursePaymentTypeStrEnum",
    "CoursePublic",
    "EmphemeralCredentials",
    "GoalEngagementPresetGet",
    "GoalInteractionsSummary",
    "HTTPValidationError",
    "InteractionType",
    "KnowledgebaseState",
    "LanguageStrEnum",
    "LocationInner",
    "ModuleLessonPublic",
    "PortalInfoRequest",
    "PortalOwnerInfo",
    "RagQueryResponse",
    "ResponseChunk",
    "ResponseChunkType",
    "ResponseWrapper",
    "ResponseWrapperAIAssistantSessionStart",
    "ResponseWrapperAiAssistantGet",
    "ResponseWrapperBool",
    "ResponseWrapperInt",
    "ResponseWrapperListAiAssistantCustomSkillGet",
    "ResponseWrapperListAiAssistantGoalGet",
    "ResponseWrapperListAiAssistantListGet",
    "ResponseWrapperListAiAssistantSkillSettingGet",
    "ResponseWrapperListAiAssistantToolSettingGet",
    "ResponseWrapperListAvatarOptionGet",
    "ResponseWrapperListGoalEngagementPresetGet",
    "ResponseWrapperListVoiceOptionGet",
    "ResponseWrapperRagQueryResponse",
    "Result",
    "Score",
    "SearchResult",
    "UsageDetails",
    "UserGoalInteractionCreate",
    "ValidationError",
    "VoiceOptionGet",
]

# import apis into sdk package
from ai_assistant_server_connector.api.ai_assistant_api_api import AiAssistantApiApi as AiAssistantApiApi
from ai_assistant_server_connector.api.assistants_api import AssistantsApi as AssistantsApi
from ai_assistant_server_connector.api.assistants_server_api import AssistantsServerApi as AssistantsServerApi
from ai_assistant_server_connector.api.avatars_api import AvatarsApi as AvatarsApi
from ai_assistant_server_connector.api.default_api import DefaultApi as DefaultApi
from ai_assistant_server_connector.api.goal_engagement_presets_api import GoalEngagementPresetsApi as GoalEngagementPresetsApi
from ai_assistant_server_connector.api.rag_api import RagApi as RagApi
from ai_assistant_server_connector.api.server_api import ServerApi as ServerApi
from ai_assistant_server_connector.api.voices_api import VoicesApi as VoicesApi

# import ApiClient
from ai_assistant_server_connector.api_response import ApiResponse as ApiResponse
from ai_assistant_server_connector.api_client import ApiClient as ApiClient
from ai_assistant_server_connector.configuration import Configuration as Configuration
from ai_assistant_server_connector.exceptions import OpenApiException as OpenApiException
from ai_assistant_server_connector.exceptions import ApiTypeError as ApiTypeError
from ai_assistant_server_connector.exceptions import ApiValueError as ApiValueError
from ai_assistant_server_connector.exceptions import ApiKeyError as ApiKeyError
from ai_assistant_server_connector.exceptions import ApiAttributeError as ApiAttributeError
from ai_assistant_server_connector.exceptions import ApiException as ApiException

# import models into sdk package
from ai_assistant_server_connector.models.ai_assistant_reponse_stream_request import AIAssistantReponseStreamRequest as AIAssistantReponseStreamRequest
from ai_assistant_server_connector.models.ai_assistant_session_start import AIAssistantSessionStart as AIAssistantSessionStart
from ai_assistant_server_connector.models.ai_assistant_custom_skill_create import AiAssistantCustomSkillCreate as AiAssistantCustomSkillCreate
from ai_assistant_server_connector.models.ai_assistant_custom_skill_get import AiAssistantCustomSkillGet as AiAssistantCustomSkillGet
from ai_assistant_server_connector.models.ai_assistant_custom_skill_patch import AiAssistantCustomSkillPatch as AiAssistantCustomSkillPatch
from ai_assistant_server_connector.models.ai_assistant_custom_skill_update import AiAssistantCustomSkillUpdate as AiAssistantCustomSkillUpdate
from ai_assistant_server_connector.models.ai_assistant_get import AiAssistantGet as AiAssistantGet
from ai_assistant_server_connector.models.ai_assistant_goal_create import AiAssistantGoalCreate as AiAssistantGoalCreate
from ai_assistant_server_connector.models.ai_assistant_goal_create_update import AiAssistantGoalCreateUpdate as AiAssistantGoalCreateUpdate
from ai_assistant_server_connector.models.ai_assistant_goal_get import AiAssistantGoalGet as AiAssistantGoalGet
from ai_assistant_server_connector.models.ai_assistant_lexicon_item import AiAssistantLexiconItem as AiAssistantLexiconItem
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_create_or_update import AiAssistantLexiconItemCreateOrUpdate as AiAssistantLexiconItemCreateOrUpdate
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_new import AiAssistantLexiconItemNew as AiAssistantLexiconItemNew
from ai_assistant_server_connector.models.ai_assistant_list_get import AiAssistantListGet as AiAssistantListGet
from ai_assistant_server_connector.models.ai_assistant_new import AiAssistantNew as AiAssistantNew
from ai_assistant_server_connector.models.ai_assistant_setting_toggle import AiAssistantSettingToggle as AiAssistantSettingToggle
from ai_assistant_server_connector.models.ai_assistant_setup_from_root import AiAssistantSetupFromRoot as AiAssistantSetupFromRoot
from ai_assistant_server_connector.models.ai_assistant_skill_setting_get import AiAssistantSkillSettingGet as AiAssistantSkillSettingGet
from ai_assistant_server_connector.models.ai_assistant_tool_setting_get import AiAssistantToolSettingGet as AiAssistantToolSettingGet
from ai_assistant_server_connector.models.ai_assistant_update import AiAssistantUpdate as AiAssistantUpdate
from ai_assistant_server_connector.models.assistant_function import AssistantFunction as AssistantFunction
from ai_assistant_server_connector.models.avatar_option_get import AvatarOptionGet as AvatarOptionGet
from ai_assistant_server_connector.models.chat_history_chat_content import ChatHistoryChatContent as ChatHistoryChatContent
from ai_assistant_server_connector.models.chat_history_item import ChatHistoryItem as ChatHistoryItem
from ai_assistant_server_connector.models.chat_message_attachment import ChatMessageAttachment as ChatMessageAttachment
from ai_assistant_server_connector.models.chat_message_attachment_type import ChatMessageAttachmentType as ChatMessageAttachmentType
from ai_assistant_server_connector.models.chat_role import ChatRole as ChatRole
from ai_assistant_server_connector.models.collection_state import CollectionState as CollectionState
from ai_assistant_server_connector.models.collection_status import CollectionStatus as CollectionStatus
from ai_assistant_server_connector.models.conversation_style import ConversationStyle as ConversationStyle
from ai_assistant_server_connector.models.course_module_public import CourseModulePublic as CourseModulePublic
from ai_assistant_server_connector.models.course_payment_type_str_enum import CoursePaymentTypeStrEnum as CoursePaymentTypeStrEnum
from ai_assistant_server_connector.models.course_public import CoursePublic as CoursePublic
from ai_assistant_server_connector.models.emphemeral_credentials import EmphemeralCredentials as EmphemeralCredentials
from ai_assistant_server_connector.models.goal_engagement_preset_get import GoalEngagementPresetGet as GoalEngagementPresetGet
from ai_assistant_server_connector.models.goal_interactions_summary import GoalInteractionsSummary as GoalInteractionsSummary
from ai_assistant_server_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from ai_assistant_server_connector.models.interaction_type import InteractionType as InteractionType
from ai_assistant_server_connector.models.knowledgebase_state import KnowledgebaseState as KnowledgebaseState
from ai_assistant_server_connector.models.language_str_enum import LanguageStrEnum as LanguageStrEnum
from ai_assistant_server_connector.models.location_inner import LocationInner as LocationInner
from ai_assistant_server_connector.models.module_lesson_public import ModuleLessonPublic as ModuleLessonPublic
from ai_assistant_server_connector.models.portal_info_request import PortalInfoRequest as PortalInfoRequest
from ai_assistant_server_connector.models.portal_owner_info import PortalOwnerInfo as PortalOwnerInfo
from ai_assistant_server_connector.models.rag_query_response import RagQueryResponse as RagQueryResponse
from ai_assistant_server_connector.models.response_chunk import ResponseChunk as ResponseChunk
from ai_assistant_server_connector.models.response_chunk_type import ResponseChunkType as ResponseChunkType
from ai_assistant_server_connector.models.response_wrapper import ResponseWrapper as ResponseWrapper
from ai_assistant_server_connector.models.response_wrapper_ai_assistant_session_start import ResponseWrapperAIAssistantSessionStart as ResponseWrapperAIAssistantSessionStart
from ai_assistant_server_connector.models.response_wrapper_ai_assistant_get import ResponseWrapperAiAssistantGet as ResponseWrapperAiAssistantGet
from ai_assistant_server_connector.models.response_wrapper_bool import ResponseWrapperBool as ResponseWrapperBool
from ai_assistant_server_connector.models.response_wrapper_int import ResponseWrapperInt as ResponseWrapperInt
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_custom_skill_get import ResponseWrapperListAiAssistantCustomSkillGet as ResponseWrapperListAiAssistantCustomSkillGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_goal_get import ResponseWrapperListAiAssistantGoalGet as ResponseWrapperListAiAssistantGoalGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_list_get import ResponseWrapperListAiAssistantListGet as ResponseWrapperListAiAssistantListGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_skill_setting_get import ResponseWrapperListAiAssistantSkillSettingGet as ResponseWrapperListAiAssistantSkillSettingGet
from ai_assistant_server_connector.models.response_wrapper_list_ai_assistant_tool_setting_get import ResponseWrapperListAiAssistantToolSettingGet as ResponseWrapperListAiAssistantToolSettingGet
from ai_assistant_server_connector.models.response_wrapper_list_avatar_option_get import ResponseWrapperListAvatarOptionGet as ResponseWrapperListAvatarOptionGet
from ai_assistant_server_connector.models.response_wrapper_list_goal_engagement_preset_get import ResponseWrapperListGoalEngagementPresetGet as ResponseWrapperListGoalEngagementPresetGet
from ai_assistant_server_connector.models.response_wrapper_list_voice_option_get import ResponseWrapperListVoiceOptionGet as ResponseWrapperListVoiceOptionGet
from ai_assistant_server_connector.models.response_wrapper_rag_query_response import ResponseWrapperRagQueryResponse as ResponseWrapperRagQueryResponse
from ai_assistant_server_connector.models.result import Result as Result
from ai_assistant_server_connector.models.score import Score as Score
from ai_assistant_server_connector.models.search_result import SearchResult as SearchResult
from ai_assistant_server_connector.models.usage_details import UsageDetails as UsageDetails
from ai_assistant_server_connector.models.user_goal_interaction_create import UserGoalInteractionCreate as UserGoalInteractionCreate
from ai_assistant_server_connector.models.validation_error import ValidationError as ValidationError
from ai_assistant_server_connector.models.voice_option_get import VoiceOptionGet as VoiceOptionGet



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from ai_assistant_server_connector.models.ai_assistant_goal_create import AiAssistantGoalCreate
from ai_assistant_server_connector.models.ai_assistant_lexicon_item_new import AiAssistantLexiconItemNew
from ai_assistant_server_connector.models.assistant_function import AssistantFunction
from ai_assistant_server_connector.models.conversation_style import ConversationStyle

class AiAssistantNew(BaseModel):
    """
    AiAssistantNew
    """
    allow_text: Optional[StrictBool] = True
    allow_voice: Optional[StrictBool] = False
    approved_urls: Optional[conlist(StrictStr)] = None
    avatar_id: Optional[StrictStr] = None
    banned_keywords: Optional[conlist(StrictStr)] = None
    conversation_starter: Optional[StrictStr] = None
    conversation_style: Optional[ConversationStyle] = None
    function: Optional[AssistantFunction] = None
    goals: Optional[conlist(AiAssistantGoalCreate)] = None
    is_active: Optional[StrictBool] = True
    is_live: Optional[StrictBool] = True
    lexicon_items: Optional[conlist(AiAssistantLexiconItemNew)] = None
    name: StrictStr = Field(...)
    prefer_voice: Optional[StrictBool] = False
    system_prompt_support: Optional[StrictStr] = None
    system_prompt_tutor: Optional[StrictStr] = None
    voice_id: Optional[StrictInt] = 1
    __properties = ["allow_text", "allow_voice", "approved_urls", "avatar_id", "banned_keywords", "conversation_starter", "conversation_style", "function", "goals", "is_active", "is_live", "lexicon_items", "name", "prefer_voice", "system_prompt_support", "system_prompt_tutor", "voice_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AiAssistantNew:
        """Create an instance of AiAssistantNew from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in goals (list)
        _items = []
        if self.goals:
            for _item in self.goals:
                if _item:
                    _items.append(_item.to_dict())
            _dict['goals'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in lexicon_items (list)
        _items = []
        if self.lexicon_items:
            for _item in self.lexicon_items:
                if _item:
                    _items.append(_item.to_dict())
            _dict['lexicon_items'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AiAssistantNew:
        """Create an instance of AiAssistantNew from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AiAssistantNew.parse_obj(obj)

        _obj = AiAssistantNew.parse_obj({
            "allow_text": obj.get("allow_text") if obj.get("allow_text") is not None else True,
            "allow_voice": obj.get("allow_voice") if obj.get("allow_voice") is not None else False,
            "approved_urls": obj.get("approved_urls"),
            "avatar_id": obj.get("avatar_id"),
            "banned_keywords": obj.get("banned_keywords"),
            "conversation_starter": obj.get("conversation_starter"),
            "conversation_style": obj.get("conversation_style"),
            "function": obj.get("function"),
            "goals": [AiAssistantGoalCreate.from_dict(_item) for _item in obj.get("goals")] if obj.get("goals") is not None else None,
            "is_active": obj.get("is_active") if obj.get("is_active") is not None else True,
            "is_live": obj.get("is_live") if obj.get("is_live") is not None else True,
            "lexicon_items": [AiAssistantLexiconItemNew.from_dict(_item) for _item in obj.get("lexicon_items")] if obj.get("lexicon_items") is not None else None,
            "name": obj.get("name"),
            "prefer_voice": obj.get("prefer_voice") if obj.get("prefer_voice") is not None else False,
            "system_prompt_support": obj.get("system_prompt_support"),
            "system_prompt_tutor": obj.get("system_prompt_tutor"),
            "voice_id": obj.get("voice_id") if obj.get("voice_id") is not None else 1
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ai_assistant_server_connector.api.server_api import ServerApi  # noqa: E501


class TestServerApi(unittest.IsolatedAsyncioTestCase):
    """ServerApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ServerApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_ai_assistant_api_server_assistant_list(self) -> None:
        """Test case for ai_assistant_api_server_assistant_list

        Server Assistant List  # noqa: E501
        """
        pass

    async def test_ai_assistant_api_server_assistant_setup_from_root(self) -> None:
        """Test case for ai_assistant_api_server_assistant_setup_from_root

        Server Assistant Setup From Root  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
